<!-- CompletedEvents 已办事件 -->
<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form ref="form" :model="parameter" label-width="auto">
                <el-row :gutter="10">
                    <el-col :span="6">
                        <el-form-item label="事件名称">
                            <el-input v-model="querys[0].value" clearable placeholder="请输入事件名称"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="6">
                        <el-form-item label="上报人">
                            <el-input v-model="querys[1].value" clearable placeholder="请输入上报人"></el-input>
                        </el-form-item>
                    </el-col>
                    
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="getData(1)">
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" :class="['main-table-container', 'flex']">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div class="table-wrapper">
                    <el-table stripe size="mini" height="100%" v-loading="tableLoading" :data="tableData"
                        :style="{ width: '100%' }" ref="table" :default-sort="{ prop: 'status', order: 'ascending' }">
                        <el-table-column type="index" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="eventName" show-overflow-tooltip min-width="120" label="事件名称" align="center">
                        </el-table-column>
                        <el-table-column prop="eventLevel" show-overflow-tooltip label="告警等级" align="center">
                            <template #default="{ row }">
                                {{ getDictName('gjdj', row.eventLevel) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="eventUrgency" show-overflow-tooltip label="紧急程度" align="center">
                            <template #default="{ row }">
                                {{ getDictName('jjcd', row.eventUrgency) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="eventType" show-overflow-tooltip min-width="120" label="事件分类" align="center">
                            <template #default="{ row }">
                                {{ getDictName('sjfl', row.eventType) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="eventSource" show-overflow-tooltip label="事件来源" align="center">
                            <template #default="{ row }">
                                {{ getDictName('sjly', row.eventSource) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="address" show-overflow-tooltip min-width="120" label="事发详细地址" align="center">
                        </el-table-column>
                        <el-table-column prop="memo" show-overflow-tooltip min-width="120" label="案由" align="center">
                        </el-table-column>
                        <el-table-column prop="briefCase" show-overflow-tooltip min-width="120" label="事发原因" align="center">
                        </el-table-column>
                        <el-table-column prop="reportPerson" show-overflow-tooltip label="上报人" align="center">
                        </el-table-column>
                        <el-table-column prop="phone" show-overflow-tooltip min-width="100" label="电话" align="center">
                        </el-table-column>
                        <el-table-column prop="eventProduceTime" show-overflow-tooltip min-width="160" label="时间"
                            align="center">
                        </el-table-column>
                        <el-table-column show-overflow-tooltip align="center" fixed="right"
                            :label="$t('common.operation')">
                            <template v-slot="{ row }">
                                <el-link type="primary" :underline="false" class="column-inner-btn"
                                    @click="handleDetail(row)">
                                    详情
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                <CompletedEventsDialog ref="formDialog" />
            </el-col>
        </el-row>
    </div>
</template>
<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import CompletedEvents from '@/api/PendingDisposal/CompletedEvents'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import CompletedEventsDialog from './components/CompletedEventsDialog'
import utils from '@/utils.js'
export default {
    name: 'CompletedEvents',
    components: {
        pagination,
        CompletedEventsDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            tableData: [
                {
                    pilotProjectName: 1,
                },
            ],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'event_name_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'report_person_',
                    relation: 'AND',
                    value: '',
                },
            ],
            reqData: {
                querys: [],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
            },
            tableLoading: false,
            deleteIds: '',
            parameter: {
                size: 20,
                page: 1,
            },
            rejectObj: {
                res: '',
            },
            rejectVisible: false,
        }
    },

    created() {
        this.getData(1)
    },
    methods: {
        handleCancel() {
            this.rejectVisible = false
        },
        handleReject() {
            this.rejectVisible = false
        },
        selectable(row) {
            if (row.isDele === '1') {
                return false
            } else {
                return true
            }
        },
        //获取数据
        getData(page) {
            if (page) {
                this.reqData.pageBean.page = page
            }
            this.tableLoading = true
            this.reqData.querys = []
            if (this.querys[0].value) {
                this.reqData.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.reqData.querys.push(this.querys[1])
            }
            CompletedEvents.dataQuery(this.reqData, (res) => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
            })
        },
        handleSizeChange(val) {
            this.reqData.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.reqData.pageBean.page = val
            this.getData()
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';
@import '~@/assets/css/common.scss';

.table-wrapper {
    height: calc(100% - 40px);
}

.btn-wrapper {
    width: 100%;
    text-align: right;
}

.column-inner-btn {
    margin: 0 5px;
}
</style>